CompiledModel

Struct CompiledModel 

pub struct CompiledModel { /* private fields */ }
A compiled model that can be used to run inference.

Implementations

Source

impl CompiledModel

pub fn create( environment: &Environment, model: &Model, options: &Options, ) -> Result<Self, Error>

Creates a new compiled model.

pub fn create_input_tensor_buffers( &self, environment: &Environment, model: &Model, signature_index: usize, ) -> Result<Vec<TensorBuffer<'_>>, Error>

Creates a set of input tensor buffers for the specified signature.

pub fn create_output_tensor_buffers( &self, environment: &Environment, model: &Model, signature_index: usize, ) -> Result<Vec<TensorBuffer<'_>>, Error>

Creates a set of output tensor buffers for the specified signature.

pub fn run( &self, signature_index: usize, input: &[TensorBuffer<'_>], output: &[TensorBuffer<'_>], ) -> Result<(), Error>

Runs inference on the compiled model.