pub struct Error { /* private fields */ }Expand description
Error returned by the bindings.
It contains the reason of the error and the LiteRtStatus returned by the C code.
Error supports fmt::Display and fmt::Debug traits.
match(litert_status) {
Ok(env) => { ... },
Err(error) => {
println!("Error: {:?}", error);
}
}Implementations
Sourceimpl Error
impl Error
Sourcepub fn cause(&self) -> ErrorCause
pub fn cause(&self) -> ErrorCause
Returns the reason of the error from the binding code.
Sourcepub fn litert_status(&self) -> LiteRtStatus
pub fn litert_status(&self) -> LiteRtStatus
Returns the LiteRtStatus returned by the C code.
Sourcepub fn litert_status_description(&self) -> String
pub fn litert_status_description(&self) -> String
Returns a string description of the LiteRtStatus returned by the C code.