TensorBuffer

Struct TensorBuffer 

pub struct TensorBuffer<'a> { /* private fields */ }

Implementations

Source

impl<'a> TensorBuffer<'a>

pub fn element_type(&self) -> ElementType

Returns the element type of the tensor buffer.

pub fn packed_size(&self) -> Result<usize, Error>

Returns the size of the tensor buffer in bytes.

pub fn write<T: 'static>(&self, data: &[T]) -> Result<usize, Error>

Writes data to the tensor buffer.

The data must be compatible with the element type of the tensor buffer. The data must be big enough to fill the tensor buffer.

Returns the number of bytes written to the tensor buffer.

pub fn read<T: 'static>(&self, data: &mut [T]) -> Result<usize, Error>

Reads data from the tensor buffer.

The data must be compatible with the element type of the tensor buffer. The data must be big enough.

Returns the number of bytes read from the tensor buffer.