pub struct TensorBufferRequirements<'a> { /* private fields */ }Expand description
Requirements for a tensor buffer.
This struct represents the requirements for a tensor buffer. It is used to determine the supported buffer types and the buffer size.
Implementations
Sourceimpl<'a> TensorBufferRequirements<'a>
impl<'a> TensorBufferRequirements<'a>
Sourcepub fn buffer_size(&self) -> Result<usize, Error>
pub fn buffer_size(&self) -> Result<usize, Error>
Returns the size of the buffer in bytes.
Sourcepub fn supported_types(&self) -> Result<Vec<TensorBufferType>, Error>
pub fn supported_types(&self) -> Result<Vec<TensorBufferType>, Error>
Returns the supported tensor buffer types.